pytilities.types.numerictype.NumericType

Package pytilities :: Package types :: Module numerictype :: Class NumericType |
[hide private]
[frames] | no frames]

# Class NumericType

source code

    object --+
             |
            NumericType

Represents any numeric type.

Numeric strings, ints (, longs) and floats are indirect instances of this class. Ints (, longs) and floats are subclasses of this class. Note that a string is not a subclass (some strings are numeric, but not all, and there is no numeric string type).

Nested Classes | [hide private]
| __metaclass__

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`